# mario_airflow_utils
### apache airflow utils

- [https://pypi.org/project/mario_airflow_utils](https://pypi.org/project/mario_airflow_utils)

```
- mario_airflow_utils is interesting and interesting.
```

# User Guide
- [https://dMario24.github.io/mario_airflow_utils](https://dMario24.github.io/mario_airflow_utils)

![logo](https://dMario24.github.io/mario_airflow_utils/img/social_preview.png)
